@@ -25,8 +25,30 @@
 #
 # File: install_logwatch.sh 
 # Author: Mike Tremaine [mgt /at/ stellarcore.net]
-# Maintainer:
-# Version: 1.0.1
+# Maintainer: Mike Tremaine [mgt /at/ stellarcore.net]
+# $Id: install_logwatch.sh 147 2013-06-18 21:43:31Z mtremaine $
+#
+# $Log: install_logwatch.sh,v $
+# Revision 1.20  2008/05/12 22:53:28  mike
+# removed -T flag no sure why it was there -mgt
+#
+# Revision 1.19  2008/05/08 23:15:55  mike
+# Added install to logwatch.cron if no cron.daily dir. -mgt
+#
+# Revision 1.18  2008/05/08 22:47:41  mike
+# Added BIGGER note for the new cron requirement -mgt
+#
+# Revision 1.17  2007/11/28 16:06:56  mike
+# Prefix option code from Craig Ruff -mgt
+#
+# Revision 1.16  2007/11/28 15:50:43  mike
+# Typod Craig Ruff sorry -mgt
+#
+# Revision 1.15  2007/11/28 15:49:47  mike
+# Patch from Craig Ruff for MANDIR under Solaris -mgt
+#
+# Revision 1.14  2007/11/28 15:43:14  mike
+# Patch from Craig Ruff for CONFIGDIR munge -mgt
 #
 # __________________________________________________________________
 #
@@ -56,6 +78,41 @@ TEMPDIR="/var/cache/logwatch"
 PERLEXE="/usr/bin/perl"
 MANDIR="/usr/share/man"
 
+#Command line options section
+#Currently only prefix is supported but now that the door is open other options should follow. -mgt
+ac_prev=
+for ac_option
+do
+   # If the previous option needs an argument, assign it.
+   if test -n "$ac_prev"; then
+      eval "$ac_prev=\$ac_option"
+      ac_prev=
+      continue
+   fi
+
+   ac_optarg=`expr "x$ac_option" : 'x[^=]*=\(.*\)'`
+
+   case $ac_option in
+      -prefix | --prefix | --prefi | --pref | --pre | --pr | --p)
+         ac_prev=prefix ;;
+      -prefix=* | --prefix=* | --prefi=* | --pref=* | --pre=* | --pr=* | --p=*)
+         prefix=$ac_optarg ;;
+      *)
+         echo "Unknown option '$ac_option'"
+         ;;
+   esac
+done
+
+if [ "x$prefix" != "x" ]; then
+   BASEDIR=$prefix
+   munge_base=1
+   CONFIGDIR=$BASEDIR/etc
+   munge_conf=1
+   TEMPDIR=$BASEDIR/tmp
+   munge_temp=1
+   MANDIR=$BASEDIR/man
+fi
+
 
 #Talk to user
 printf "#################################\n"
@@ -73,7 +130,7 @@ else
 fi
 
 printf "Enter the path for the Logwatch ConfigDir [$CONFIGDIR] : "
-read config  
+read config
 
 if [ "$config" = "" ]; then
    printf "### Using $CONFIGDIR\n"
@@ -168,7 +225,7 @@ install -m 0755 -d $CONFIGDIR/conf/services
 install -m 0755 -d $CONFIGDIR/conf/html
 
 if [ $munge_conf ]; then
-   perl -pi -e "s%/etc/logwatch/conf%$CONFIGDIR/conf%" $BASEDIR/scripts/logwatch.pl
+   perl -pi -e "s%/etc/logwatch%$CONFIGDIR%" $BASEDIR/scripts/logwatch.pl
 fi
 
 touch $CONFIGDIR/conf/logwatch.conf
@@ -206,35 +263,56 @@ for f in `echo $PATH | tr : ' '`; do
 done
 
 #Man page
-if [ -d $MANDIR/man8 ] && [ $HAVE_MAKEWHATIS ]; then
+if [ -d $MANDIR/man5 ] && [ -d $MANDIR/man8 ] && [ -d $MANDIR/man1 ] && [ $HAVE_MAKEWHATIS ]; then
    install -m 0644 logwatch.8 $MANDIR/man8
+   install -m 0644 logwatch.conf.5 $MANDIR/man5
+   install -m 0644 override.conf.5 $MANDIR/man5
+   install -m 0644 ignore.conf.5 $MANDIR/man5
+   install -m 0644 postfix-logwatch.1 $MANDIR/man1
+   install -m 0644 amavis-logwatch.1 $MANDIR/man1
    #OpenBSD no -s
    if [ $OS = "OpenBSD" ]; then
-      makewhatis -u $MANDIR/man8
+      makewhatis -u $MANDIR/man5 $MANDIR/man8 $MANDIR/man1
    else
       #FreeBSD and NetBSD no -s no -u
       if [ $OS = "FreeBSD" ] || [ $OS = "NetBSD" ]; then
-         makewhatis $MANDIR/man8
+         makewhatis $MANDIR/man5 $MANDIR/man8 $MANDIR/man1
       else
          #MacOS X aka Darwin no -u [even thought the manpage says]
          if [ $OS = "Darwin" ]; then
-            makewhatis -s 8 $MANDIR
+            makewhatis -s "1 5 8" $MANDIR
          else
          #Linux
-            makewhatis -u -s 8 $MANDIR
+            makewhatis -u -s "1 5 8" $MANDIR
          fi
       fi
    fi
 else
    if [ $OS = "SunOS" ]; then
       #Go for the safe install rather then editing man.cf
+      mkdir -p $MANDIR/man1m > /dev/null 2>&1
       install -m 0644 logwatch.8 $MANDIR/man1m
-      catman -w -M /usr/share/man/man1m
+      install -m 0644 logwatch.conf.5 $MANDIR/man1m
+      install -m 0644 override.conf.5 $MANDIR/man1m
+      install -m 0644 ignore.conf.5 $MANDIR/man1m
+      install -m 0644 postfix-logwatch.1 $MANDIR/man1
+      install -m 0644 amavis-logwatch.1 $MANDIR/man1
+      catman -w -M $MANDIR/man1m
    else
+      install -m 0755 -d $MANDIR/man1
+      install -m 0644 postfix-logwatch.1 $MANDIR/man1
+      install -m 0644 amavis-logwatch.1 $MANDIR/man1
+
+      install -m 0755 -d $MANDIR/man5
+      install -m 0644 logwatch.conf.5 $MANDIR/man5
+      install -m 0644 override.conf.5 $MANDIR/man5
+      install -m 0644 ignore.conf.5 $MANDIR/man5
+
       install -m 0755 -d $MANDIR/man8
       install -m 0644 logwatch.8 $MANDIR/man8
-      printf "Installed manpage in $MANDIR/man8.\n"
-      printf "Check your man.cf or man.conf to enable MANSECTS 8\n"
+
+      printf "Installed manpages in $MANDIR/man1, $MANDIR/man5 and $MANDIR/man8.\n"
+      printf "Check your man.cf or man.conf to enable MANSECTS 1, 5 and 8\n"
    fi
 fi
 
@@ -245,11 +323,14 @@ printf "Created symlink for /usr/sbin/logwatch \n"
 #Cron
 if [ -d /etc/cron.daily ]; then
    rm -f /etc/cron.daily/0logwatch
-   ln -s $BASEDIR/scripts/logwatch.pl /etc/cron.daily/0logwatch
+   install -m 0755 logwatch.cron /etc/cron.daily/0logwatch
    printf "Created /etc/cron.daily/0logwatch \n" 
 else
-   printf "You need to setup your cron job for logwatch, something like \n"
-   printf "2 0 * * * $BASEDIR/scripts/logwatch.pl >/dev/null 2>&1 \n"
+   install -m 0744 logwatch.cron $CONFIGDIR/logwatch.cron
+   printf "################ README ####################.\n"
+   printf "You need to setup your cron job for logwatch.\n"
+   printf "A sample script is included see $CONFIGDIR/logwatch.cron. \n"
+   printf "2 0 * * * $CONFIGDIR/logwatch.cron >/dev/null 2>&1 \n"
 fi
 
 exit
